Module cli

Module cli 

Enclave CLI args and types.

Modules

node
User node CLI args.

Structs

LspFees
Information about Lexe’s LSP’s fees.
LspInfo
Information about the LSP which the user node needs to connect and to generate route hints when no channel exists.
OAuthConfig
Configuration info relating to Google OAuth2. When combined with an auth code, can be used to obtain a GDrive access token and refresh token.

Traits

EnclaveArgs
A trait for the arguments to an enclave command.