pub trait EnclaveArgs: Serialize + DeserializeOwned {
const NAME: &str;
// Provided methods
fn to_command(&self, bin_path: &Path) -> Command { ... }
fn append_args(&self, cmd: &mut Command) { ... }
fn from_json_str(json_str: &str) -> Result<Self, Error> { ... }
fn to_json_string(&self) -> String { ... }
}Expand description
A trait for the arguments to an enclave command.
Required Associated Constants
Provided Methods
Sourcefn to_command(&self, bin_path: &Path) -> Command
fn to_command(&self, bin_path: &Path) -> Command
Construct a std::process::Command from the contained args.
Requires the path to the binary.
Sourcefn append_args(&self, cmd: &mut Command)
fn append_args(&self, cmd: &mut Command)
Serialize and append the contained args to an existing
std::process::Command.
fn from_json_str(json_str: &str) -> Result<Self, Error>
fn to_json_string(&self) -> String
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.