BearerAuthBackendApi

Trait BearerAuthBackendApi 

pub trait BearerAuthBackendApi {
    // Required method
    fn bearer_auth<'life0, 'life1, 'life2, 'async_trait>(
        &'life0 self,
        signed_req: &'life1 Signed<&'life2 BearerAuthRequestWire>,
    ) -> Pin<Box<dyn Future<Output = Result<BearerAuthResponse, BackendApiError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait,
             'life2: 'async_trait;
}
The bearer auth API exposed by the backend (sometimes via the gateway) to various consumers. This trait is defined separately from the usual ConsumerServiceApi traits because BearerAuthenticator needs to abstract over a generic implementor of BearerAuthBackendApi.

Required Methods

fn bearer_auth<'life0, 'life1, 'life2, 'async_trait>( &'life0 self, signed_req: &'life1 Signed<&'life2 BearerAuthRequestWire>, ) -> Pin<Box<dyn Future<Output = Result<BearerAuthResponse, BackendApiError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait, 'life2: 'async_trait,

POST /CONSUMER/bearer_auth ed25519::Signed<BearerAuthRequest> -> BearerAuthResponse

Valid values for CONSUMER are: “app”, “node” and “lsp”.

Implementors