API error types. Serializable api error types and error kinds returned by various lexe services.
Modules
Structs
- Backend
ApiError - Common
ApiError - Errors common to all
ApiErrors. - Error
Response ErrorResponseis the common JSON-serialized representation for allApiErrors. It is the only error struct actually sent across the wire. Everything else is converted to / from it.- Gateway
ApiError - LspApi
Error - Mega
ApiError - Node
ApiError - Runner
ApiError - SdkApi
Error
Enums
- Backend
Error Kind - All variants of errors that the backend can return.
- Common
Error Kind - Error variants common to all
ApiErrors. - Gateway
Error Kind - All variants of errors that the gateway can return.
- LspError
Kind - All variants of errors that the LSP can return.
- Mega
Error Kind - All variants of errors that the LSP can return.
- Node
Error Kind - All variants of errors that the node can return.
- Runner
Error Kind - All variants of errors that the runner can return.
- SdkError
Kind - All variants of errors that the SDK can return.
Constants
- CLIENT_
400_ BAD_ REQUEST - CLIENT_
401_ UNAUTHORIZED - CLIENT_
404_ NOT_ FOUND - CLIENT_
409_ CONFLICT - SERVER_
500_ INTERNAL_ SERVER_ ERROR - SERVER_
502_ BAD_ GATEWAY - SERVER_
503_ SERVICE_ UNAVAILABLE - SERVER_
504_ GATEWAY_ TIMEOUT
Traits
- ApiError
- A ‘trait alias’ defining all the supertraits an API error type must impl
to be accepted for use in the
RestClientand across all Lexe APIs. - ApiError
Kind ApiErrorKinddefines the methods required of all API error kinds. Implementations of this trait are derived byapi_error_kind!.- ToHttp
Status - A trait to get the HTTP status code for a given Error.
Functions
- join_
results - Converts a
Vec<anyhow::Result<()>>to ananyhow::Result<()>, with any error messages joined by a semicolon.
Type Aliases
- Error
Code ErrorCodeis the common serialized representation for allErrorKinds.