pub enum GatewayErrorKind {
Unknown(ErrorCode),
UnknownReqwest,
Building,
Connect,
Timeout,
Decode,
Server,
Rejection,
AtCapacity,
FiatRatesMissing,
}Expand description
All variants of errors that the gateway can return.
Variants
Unknown(ErrorCode)
Unknown error
UnknownReqwest
Unknown Reqwest client error
Building
Error building the HTTP request
Connect
Error connecting to a remote HTTP service
Timeout
Request timed out
Decode
Error decoding/deserializing the HTTP response body
Server
General server error
Rejection
Client provided a bad request that the server rejected
AtCapacity
Server is at capacity
FiatRatesMissing
Missing fiat exchange rates; issue with upstream data source