pub struct ErrorResponse {
pub code: ErrorCode,
pub msg: String,
pub data: Value,
pub sensitive: bool,
}Expand description
ErrorResponse is the common JSON-serialized representation for all
ApiErrors. It is the only error struct actually sent across the wire.
Everything else is converted to / from it.
For displaying the full human-readable message to the user, convert
ErrorResponse to the corresponding API error type first.
Fields
code: ErrorCodemsg: Stringdata: ValueStructured data associated with this error.
sensitive: boolWhether data contains sensitive information that Lexe shouldn’t see
(e.g. a route). Such data may still be logged by the app or in SDKs but
shouldn’t be logged inside of Lexe infra.