api_error

Macro api_error 

macro_rules! api_error {
    ($api_error:ident, $api_error_kind:ident) => { ... };
}
This macro takes the name of an ApiError and its error kind type to generate the various impls required by the ApiError trait alias.

This macro should be used in combination with api_error_kind! below.

api_error!(FooApiError, FooErrorKind);