macro_rules! user_agent_to_external {
() => { ... };
}Expand description
Build the user agent string used for requests to external services at compile time.
Example: “lexe-node/0.6.20”.
macro_rules! user_agent_to_external {
() => { ... };
}Build the user agent string used for requests to external services at compile time.
Example: “lexe-node/0.6.20”.