pub struct ClaimGeneratedHumanBitcoinAddress {
pub offer: Offer,
pub username: Username,
}Expand description
Claims a generated human Bitcoin address.
This endpoint is used during node initialization to claim an auto-generated
human Bitcoin address. The address will have is_primary: false and
is_generated: true.
Fields
offer: OfferOffer to be used to fetch invoices on BIP-353.
username: UsernameThe username to claim. This must be the username returned by
get_generated_username.