pub struct PayInvoiceRequest {
pub invoice: Invoice,
pub fallback_amount: Option<Amount>,
pub note: Option<BoundedNote>,
pub payer_note: Option<BoundedNote>,
}Fields
invoice: InvoiceThe invoice we want to pay.
fallback_amount: Option<Amount>Specifies the amount we will pay if the invoice to be paid is
amountless. This field must be Some for amountless invoices.
note: Option<BoundedNote>An optional personal note for this payment, useful if the receiver-provided description is insufficient.
payer_note: Option<BoundedNote>An optional payer note to persist with this outbound payment. For
LNURL-pay, this is the LUD-12 comment sent during invoice
negotiation.