pub struct PayOnchainPreflightResponse {
pub high: Option<FeeEstimate>,
pub normal: FeeEstimate,
pub background: FeeEstimate,
}Fields
high: Option<FeeEstimate>Corresponds with ConfirmationPriority::High
The high estimate is optional–we don’t want to block the user from sending if they only have enough for a normal tx fee.
normal: FeeEstimateCorresponds with ConfirmationPriority::Normal
background: FeeEstimateCorresponds with ConfirmationPriority::Background