pub struct UpdatePaymentNote {
pub index: PaymentCreatedIndex,
pub note: Option<BoundedNote>,
}Expand description
A request to update the personal note on a payment. Pass None to clear.
Fields
index: PaymentCreatedIndexThe index of the payment whose note should be updated.
note: Option<BoundedNote>The updated note, or None to clear.