pub struct CreateInvoiceRequest {
pub expiry_secs: u32,
pub amount: Option<Amount>,
pub description: Option<String>,
pub description_hash: Option<[u8; 32]>,
pub message: Option<BoundedString>,
pub partner_pk: Option<UserPk>,
pub partner_prop_fee: Option<Ppm>,
pub partner_base_fee: Option<Amount>,
}Fields
expiry_secs: u32amount: Option<Amount>The amount to encode into the invoice.
description: Option<String>The description to be encoded into the invoice.
If None, the description field inside the invoice will be an empty
string (“”), as lightning requires a description (or description
hash) to be set.
NOTE: If both description and description_hash are set, node will
return an error.
description_hash: Option<[u8; 32]>A 256-bit hash. Commonly a hash of a long description.
This field is used to associate description longer than 639 bytes to
the invoice. Also known as ‘h tag in BOLT11’.
This field is required to build invoices for the LNURL (LUD06)
receiving flow. Not used in other flows.
NOTE: If both description and description_hash are set, node will
return an error.
message: Option<BoundedString>An optional message from the payer, stored with this inbound payment.
For LNURL-pay, set from the LUD-12 comment.
partner_pk: Option<UserPk>The partner’s user_pk, if the partner is setting the fee for this payment instead of using Lexe’s default fees.
This must be set in order for partner_prop_fee and partner_base_fee
to take effect.
partner_prop_fee: Option<Ppm>The partner-chosen proportional fee to charge on this payment.
If partner_pk is set, this must be set to Some.
Minimum: 5000 ppm (LSP_USERNODE_SKIM_FEE_PPM)
Maximum: 500,000 ppm (50%)
partner_base_fee: Option<Amount>The partner-chosen base fee to charge on this payment.
If this is set, the invoice amount must also be set.