CreateInvoiceRequest

Struct CreateInvoiceRequest 

pub struct CreateInvoiceRequest {
    pub expiry_secs: u32,
    pub amount: Option<Amount>,
    pub description: Option<String>,
    pub description_hash: Option<[u8; 32]>,
    pub payer_note: Option<BoundedNote>,
}

Fields

expiry_secs: u32amount: Option<Amount>description: Option<String>

The description to be encoded into the invoice.

If None, the description field inside the invoice will be an empty string (“”), as lightning requires a description (or description hash) to be set. NOTE: If both description and description_hash are set, node will return an error.

description_hash: Option<[u8; 32]>

A 256-bit hash. Commonly a hash of a long description.

This field is used to associate description longer than 639 bytes to the invoice. Also known as ‘h tag in BOLT11’.

This field is required to build invoices for the LNURL (LUD06) receiving flow. Not used in other flows. NOTE: If both description and description_hash are set, node will return an error.

payer_note: Option<BoundedNote>

An optional note from the payer, stored with this inbound payment. For LNURL-pay, set from the LUD-12 comment.